module MyPrayerJournal.Views.Docs

open Giraffe.ViewEngine

/// The "About myPrayerJournal" section
let private about = [
    h3 [ _class "mb-3 mt-4" ] [ rawText "About myPrayerJournal" ]
    p [] [
        rawText "Journaling has a long history; it helps people remember what happened, and the act of writing helps "
        rawText "people think about what happened and process it. A prayer journal is not a new concept; it helps you "
        rawText "keep track of the requests for which you've prayed, you can use it to pray over things repeatedly, "
        rawText "and you can write the result when the answer comes "; em [] [ rawText "(or it was &ldquo;no&rdquo;)" ]
        rawText "."
    ]
    p [] [
        rawText "myPrayerJournal was borne of out of a personal desire "
        a [ _href "https://daniel.summershome.org"; _target "_blank"; _rel "noopener" ] [ rawText "Daniel" ]
        rawText " had to have something that would help him with his prayer life. When it&rsquo;s time to pray, "
        rawText "it&rsquo;s not really time to use an app, so the design goal here is to keep it simple and "
        rawText "unobtrusive. It will also help eliminate some of the downsides to a paper prayer journal, like not "
        rawText "remembering whether you&rsquo;ve prayed for a request, or running out of room to write another update "
        rawText "on one."
    ]
]

/// The "Signing Up" section
let private signUp = [
    h3 [ _class "mb-3 mt-4" ] [ rawText "Signing Up" ]
    p [] [
        rawText "myPrayerJournal uses login services using Google or Microsoft accounts. The only information the "
        rawText "application stores in its database is your user Id token it receives from these services, so there "
        rawText "are no permissions you should have to accept from these provider other than establishing that you can "
        rawText "log on with that account. Because of this, you&rsquo;ll want to pick the same one each time; the "
        rawText "tokens between the two accounts are different, even if you use the same e-mail address to log on to "
        rawText "both."
    ]
]

/// The "Your Prayer Journal" section
let private yourJournal = [
    h3 [ _class "mb-3 mt-4" ] [ rawText "Your Prayer Journal" ]
    p [] [
        rawText "Your current requests will be presented in columns (usually three, but it could be more or less, "
        rawText "depending on the size of your screen or device). Each request is in its own card, and the buttons at "
        rawText "the top of each card apply to that request. The last line of each request also tells you how long it "
        rawText "has been since anything has been done on that request. Any time you see something like &ldquo;a few "
        rawText "minutes ago,&rdquo; you can hover over that to see the actual date/time the action was taken."
    ]
]

/// The "Adding a Request" section
let private addRequest = [
    h3 [ _class "mb-3 mt-4" ] [ rawText "Adding a Request" ]
    p [] [
        rawText "To add a request, click the &ldquo;Add a New Request&rdquo; button at the top of your journal. Then, "
        rawText "enter the text of the request as you see fit; there is no right or wrong way, and you are the only "
        rawText "person who will see the text you enter. When you save the request, it will go to the bottom of the "
        rawText "list of requests."
    ]
]

/// The "Setting Request Recurrence" section
let private setRecurrence = [
    h3 [ _class "mb-3 mt-4" ] [ rawText "Setting Request Recurrence" ]
    p [] [
        rawText "When you add or update a request, you can choose whether requests go to the bottom of the journal "
        rawText "once they have been marked &ldquo;Prayed&rdquo; or whether they will reappear after a delay. You can "
        rawText "set recurrence in terms of hours, days, or weeks, but it cannot be longer than 365 days. If you "
        rawText "decide you want a request to reappear sooner, you can skip the current delay; click the "
        rawText "&ldquo;Active&rdquo; menu link, find the request in the list (likely near the bottom), and click the "
        rawText "&ldquo;Show Now&rdquo; button."
    ]
]

/// The "Praying for Requests" section
let private praying = [
    h3 [ _class "mb-3 mt-4" ] [ rawText "Praying for Requests" ]
    p [] [
        rawText "The first button for each request has a checkmark icon; clicking this button will mark the request as "
        rawText "&ldquo;Prayed&rdquo; and move it to the bottom of the list (or off, if you&rsquo;ve set a recurrence "
        rawText "period for the request). This allows you, if you&rsquo;re praying through your requests, to start at "
        rawText "the top left (with the request that it&rsquo;s been the longest since you&rsquo;ve prayed) and click "
        rawText "the button as you pray; when the request move below or away, the next-least-recently-prayed request "
        rawText "will take the top spot."
    ]
]

/// The "Editing Requests" section
let private editing = [
    h3 [ _class "mb-3 mt-4" ] [ rawText "Editing Requests" ]
    p [] [
        rawText "The second button for each request has a pencil icon. This allows you to edit the text of the "
        rawText "request, pretty much the same way you entered it; it starts with the current text, and you can add to "
        rawText "it, modify it, or completely replace it. By default, updates will go in with an &ldquo;Updated&rdquo; "
        rawText "status; you have the option to also mark this update as &ldquo;Prayed&rdquo; or "
        rawText "&ldquo;Answered&rdquo;. Answered requests will drop off the journal list."
    ]
]

/// The "Adding Notes" section
let private addNotes = [
    h3 [ _class "mb-3 mt-4" ] [ rawText "Adding Notes" ]
    p [] [
        rawText "The third button for each request has an icon that looks like a speech bubble with lines on it; this "
        rawText "lets you record notes about the request. If there is something you want to record that doesn&rsquo;t "
        rawText "change the text of the request, this is the place to do it. For example, you may be praying for a "
        rawText "long-term health issue, and that person tells you that their status is the same; or, you may want to "
        rawText "record something God said to you while you were praying for that request."
    ]
]

/// The "Snoozing Requests" section
let private snoozing = [
    h3 [ _class "mb-3 mt-4" ] [ rawText "Snoozing Requests" ]
    p [] [
        rawText "There may be a time where a request does not need to appear. The fourth button, with the clock icon, "
        rawText "allows you to snooze requests until the day you specify. Additionally, if you have any snoozed "
        rawText "requests, a &ldquo;Snoozed&rdquo; menu item will appear next to the &ldquo;Journal&rdquo; one; this "
        rawText "page allows you to see what requests are snoozed, and return them to your journal by canceling the "
        rawText "snooze."
    ]
]

/// The "Viewing a Request and Its History" section
let private viewing = [
    h3 [ _class "mb-3 mt-4" ] [ rawText "Viewing a Request and Its History" ]
    p [] [
        rawText "myPrayerJournal tracks all of the actions related to a request; from the &ldquo;Active&rdquo; and "
        rawText "&ldquo;Answered&rdquo; menu links (and &ldquo;Snoozed&rdquo;, if it&rsquo;s showing), there is a "
        rawText "&ldquo;View Full Request&rdquo; button. That page will show the current text of the request; how many "
        rawText "times it has been marked as prayed; how long it has been an active request; and a log of all updates, "
        rawText "prayers, and notes you have recorded. That log is listed from most recent to least recent; if you "
        rawText "want to read it chronologically, press the &ldquo;End&rdquo; key on your keyboard and read it from "
        rawText "the bottom up."
    ]
    p [] [
        rawText "The &ldquo;Active&rdquo; link will show all requests that have not yet been marked answered, "
        rawText "including snoozed and recurring requests. If requests are snoozed, or in a recurrence period off the "
        rawText "journal, there will be a button where you can return the request to the list (either &ldquo;Cancel "
        rawText "Snooze&rdquo; or &ldquo;Show Now&rdquo;). The &ldquo;Answered&rdquo; link shows all requests that "
        rawText "have been marked answered. The &ldquo;Snoozed&rdquo; link only shows snoozed requests."
    ]
]

/// The "Final Notes" section
let private finalNotes = [
    h3 [ _class "mb-3 mt-4" ] [ rawText "Final Notes" ]
    ul [] [
        li [] [
            rawText "If you encounter errors, please "
            a [ _href "https://git.bitbadger.solutions/bit-badger/myPrayerJournal/issues"; _target "_blank" ] [
                rawText "file an issue"
            ]; rawText " (or "
            a [ _href "mailto:daniel@bitbadger.solutions?subject=myPrayerJournal+Issue" ] [ rawText "e-mail Daniel" ]
            rawText " if you do not have an account on that server) with as much detail as possible. You can also "
            rawText "provide suggestions, or browse the list of currently open issues."
        ]
        li [] [
            rawText "Prayer requests and their history are securely backed up nightly along with other Bit Badger "
            rawText "Solutions data."
        ]
        li [] [
            rawText "Prayer changes things - most of all, the one doing the praying. I pray that this tool enables you "
            rawText "to deepen and strengthen your prayer life."
        ]
    ]
]

/// The documentation page
let index =
    article [ _class "container mt-3" ] [
        h2 [ _class "mb-3" ] [ rawText "Documentation" ]
        yield! about
        yield! signUp
        yield! yourJournal
        yield! addRequest
        yield! setRecurrence
        yield! praying
        yield! editing
        yield! addNotes
        yield! snoozing
        yield! viewing
        yield! finalNotes
    ]
