<?php declare(strict_types=1);

use BitBadger\PDODocument\{Configuration, Definition, Mode};
use Dotenv\Dotenv;
use MyPrayerJournal\{Auth, Layout, Table};

require __DIR__ . '/vendor/autoload.php';

/** The version of this application */
const MPJ_VERSION = '4.0.0-alpha1';

(Dotenv::createImmutable(__DIR__))->load();
session_start();

$auth0_session = Auth::client()->getCredentials();
if (!is_null($auth0_session)) {
    $_SESSION['user_id'] = $auth0_session->user['sub'];
}

Configuration::$pdoDSN = 'sqlite:' . implode(DIRECTORY_SEPARATOR, [__DIR__, 'data', 'mpj.db']);
Configuration::$mode   = Mode::SQLite;
Definition::ensureTable(Table::REQUEST);

/**
 * Is this an htmx request?
 *
 * @return bool True if this is an htmx request, false if not
 */
function is_htmx(): bool
{
    return key_exists('HTTP_HX_REQUEST', $_SERVER) && !key_exists('HTTP_HX_HISTORY_RESTORE_REQUEST', $_SERVER);
}

function page_link(string $href, string $text, array $attrs = []): void
{
    echo '<a href="' . $href . '" hx-get="' . $href . '" hx-target="#top" hx-swap=innerHTML hx-push-url=true';
    foreach ($attrs as $key => $value) echo " $key=\"" . htmlspecialchars($value) . "\"";
    echo ">$text</a>";
}

/**
 * Generate a material icon
 *
 * @param string $name The name of the material icon
 * @return string The material icon wrapped in a `span` tag
 */
function icon(string $name): string {
    return "<span class=material-icons>$name</span>";
}

function page_head(string $title): void
{
    Layout::htmlHead($title);
    echo '<body>';
    if (!is_htmx()) echo '<section id=top aria-label="Top navigation">';
    Layout::navBar();
    echo '<main role=main>';
}

function bare_head(): void
{
    echo '<!DOCTYPE html><html lang=en><head><title></title></head><body>';
}

function page_foot(): void
{
    echo '</main>';
    if (!is_htmx()) {
        echo '</section>';
        Layout::htmlFoot();
    }
    echo '</body></html>';
}

function bare_foot(): void
{
    echo '</body></html>';
}
